@@ -173,9 +173,9 @@ class ModelBase(h2o_meta(Keyed)):
                     data={"predict_staged_proba": True})
         return h2o.get_frame(j["predictions_frame"]["name"])
 
-    def predict_contributions(self, test_data):
+    def predict_contributions(self, test_data, output_format="Original"):
         """
-        Predict feature contributions - SHAP values on an H2O Model (only DRF, GBM and XGBoost models).
+        Predict feature contributions - SHAP values on an H2O Model (only GBM, XGBoost and DRF models).
         
         Returned H2OFrame has shape (#rows, #features + 1) - there is a feature contribution column for each input
         feature, the last column is the model bias (same value for each row). The sum of the feature contributions
@@ -186,12 +186,17 @@ class ModelBase(h2o_meta(Keyed)):
         Note: Multinomial classification models are currently not supported.
 
         :param H2OFrame test_data: Data on which to calculate contributions.
+        :param Enum output_format: Specify how to output feature contributions in XGBoost - XGBoost by default outputs 
+            contributions for 1-hot encoded features, specifying a Compact output format will produce a per-feature
+            contribution. One of: ``"Original"``, ``"Compact"`` (default: ``"Original"``).
 
         :returns: A new H2OFrame made of feature contributions.
         """
+        assert_is_type(output_format, None, Enum("Original", "Compact"))
         if not isinstance(test_data, h2o.H2OFrame): raise ValueError("test_data must be an instance of H2OFrame")
         j = H2OJob(h2o.api("POST /4/Predictions/models/%s/frames/%s" % (self.model_id, test_data.frame_id),
-                           data={"predict_contributions": True}), "contributions")
+                           data={"predict_contributions": True, "predict_contributions_output_format": output_format}),
+                   "contributions")
         j.poll()
         return h2o.get_frame(j.dest_key)
 
@@ -382,8 +387,6 @@ class ModelBase(h2o_meta(Keyed)):
         model = self._model_json["output"]
         if "scoring_history" in model and model["scoring_history"] is not None:
             return model["scoring_history"].as_data_frame()
-        if "glm_scoring_history" in model and model["glm_scoring_history"] is not None:
-            return model["glm_scoring_history"].as_data_frame()
         print("No score history for this model")
 
     def ntrees_actual(self):
@@ -418,9 +421,10 @@ class ModelBase(h2o_meta(Keyed)):
         :param max_interaction_depth: Upper bound for extracted feature interactions depth. Defaults to 100.
         :param max_tree_depth: Upper bound for tree depth. Defaults to 100.
         :param max_deepening: Upper bound for interaction start deepening (zero deepening => interactions 
-        starting at root only). Defaults to -1.
-        :param path: Path where to save the output in .xlsx format. Please note that Pandas and XlsxWriter need to be 
-        installed for using this option. Defaults to None.
+            starting at root only). Defaults to -1.
+        :param path: (Optional) Path where to save the output in .xlsx format (e.g. ``/mypath/file.xlsx``).
+            Please note that Pandas and XlsxWriter need to be installed for using this option. Defaults to None.
+
 
         :examples:
         >>> boston = h2o.import_file("https://s3.amazonaws.com/h2o-public-test-data/smalldata/gbm_test/BostonHousing.csv")
